@@ -12,15 +12,15 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-import os
 from pathlib import Path
 
 import eva
 
-EVA_INSTALLATION_DIR = os.path.dirname(eva.__file__)
-EVA_DEFAULT_DIR = str(Path.home()) + "/.eva/"
+EVA_INSTALLATION_DIR = Path(eva.__file__).parent
+EVA_DEFAULT_DIR = Path.home() / ".eva"
 EVA_DATASET_DIR = "eva_datasets"
+EVA_UPLOAD_DIR = "tmp"
 EVA_CONFIG_FILE = "eva.yml"
 CATALOG_DIR = "catalog"
 DATASET_DATAFRAME_NAME = "dataset"
-DB_DEFAULT_URI = "sqlite:///{}eva_catalog.db".format(EVA_DEFAULT_DIR)
+DB_DEFAULT_URI = "sqlite:///{}/eva_catalog.db".format(EVA_DEFAULT_DIR.resolve())
