@@ -18,6 +18,7 @@ from unittest.mock import MagicMock, patch
 from eva.binder.binder_utils import BinderError
 from eva.binder.statement_binder import StatementBinder
 from eva.binder.statement_binder_context import StatementBinderContext
+from eva.parser.alias import Alias
 from eva.parser.types import FileFormatType
 
 
@@ -44,7 +45,9 @@ class StatementBinderTests(unittest.TestCase):
             tableref = MagicMock()
             tableref.is_table_atom.return_value = True
             binder._bind_tableref(tableref)
-            mock.assert_called_with(tableref.alias, tableref.table.table_name)
+            mock.assert_called_with(
+                tableref.alias.alias_name, tableref.table.table_name
+            )
             mock_bind_tabe_info.assert_called_once_with(tableref.table)
 
         with patch.object(StatementBinder, "bind") as mock_binder:
@@ -57,7 +60,8 @@ class StatementBinderTests(unittest.TestCase):
                 tableref.is_select.return_value = True
                 binder._bind_tableref(tableref)
                 mock_context.assert_called_with(
-                    tableref.alias, tableref.select_statement.target_list
+                    tableref.alias.alias_name,
+                    tableref.select_statement.target_list,
                 )
                 mock_binder.assert_called_with(tableref.select_statement)
 
@@ -69,7 +73,7 @@ class StatementBinderTests(unittest.TestCase):
             tableref.is_select.return_value = False
             tableref.is_join.return_value = False
             binder._bind_tableref(tableref)
-            mock_binder.assert_called_with(tableref.func_expr)
+            mock_binder.assert_called_with(tableref.table_valued_expr.func_expr)
 
     def test_bind_tableref_with_join(self):
         with patch.object(StatementBinder, "bind") as mock_binder:
@@ -88,7 +92,7 @@ class StatementBinderTests(unittest.TestCase):
                 binder = StatementBinder(StatementBinderContext())
                 tableref = MagicMock()
                 tableref.is_select.return_value = False
-                tableref.is_func_expr.return_value = False
+                tableref.is_table_valued_expr.return_value = False
                 tableref.is_join.return_value = False
                 tableref.is_table_atom.return_value = False
                 binder._bind_tableref(tableref)
@@ -115,7 +119,10 @@ class StatementBinderTests(unittest.TestCase):
     @patch("eva.binder.statement_binder.path_to_class")
     def test_bind_func_expr(self, mock_path_to_class, mock_catalog):
         # setup
-        func_expr = MagicMock(alias="func_expr", output_col_aliases=[])
+        func_expr = MagicMock(
+            name="func_expr", alias=Alias("func_expr"), output_col_aliases=[]
+        )
+        func_expr.name.lower.return_value = "func_expr"
         obj1 = MagicMock()
         obj1.name.lower.return_value = "out1"
         obj2 = MagicMock()
@@ -138,14 +145,16 @@ class StatementBinderTests(unittest.TestCase):
         mock_get_udf_outputs.assert_called_with(udf_obj)
         mock_path_to_class.assert_called_with(udf_obj.impl_file_path, udf_obj.name)
         self.assertEqual(func_expr.output_objs, [obj1])
+        print(str(func_expr.alias))
         self.assertEqual(
-            func_expr.output_col_aliases,
-            ["{}.{}".format(func_expr.alias, obj1.name.lower())],
+            func_expr.alias,
+            Alias("func_expr", ["out1"]),
         )
         self.assertEqual(func_expr.function, "path_to_class")
 
         # Case 2 output not set
         func_expr.output = None
+        func_expr.alias = Alias("func_expr")
         binder = StatementBinder(StatementBinderContext())
         binder._bind_func_expr(func_expr)
 
@@ -154,7 +163,11 @@ class StatementBinderTests(unittest.TestCase):
         mock_path_to_class.assert_called_with(udf_obj.impl_file_path, udf_obj.name)
         self.assertEqual(func_expr.output_objs, func_ouput_objs)
         self.assertEqual(
-            func_expr.output_col_aliases, ["func_expr.out1", "func_expr.out2"]
+            func_expr.alias,
+            Alias(
+                "func_expr",
+                ["out1", "out2"],
+            ),
         )
         self.assertEqual(func_expr.function, "path_to_class")
 
@@ -228,6 +241,31 @@ class StatementBinderTests(unittest.TestCase):
             mock_binder.assert_any_call(tve_return_value)
             self.assertEqual(load_statement.column_list, [tve_return_value])
 
+    @patch("eva.binder.statement_binder.create_video_metadata")
+    @patch("eva.binder.statement_binder.TupleValueExpression")
+    def test_bind_upload_video_statement(self, mock_tve, mock_create):
+        upload_statement = MagicMock()
+        upload_statement.file_options = {"file_format": FileFormatType.VIDEO}
+        upload_statement.column_list = None
+        column = MagicMock()
+        table_ref_obj = MagicMock()
+        table_ref_obj.columns = [column]
+        table_ref_obj.name = "table_alias"
+        upload_statement.table_ref.table.table_obj = table_ref_obj
+        upload_statement.table_ref.table.table_name = "table_name"
+        mock_tve.return_value = tve_return_value = MagicMock()
+
+        with patch.object(StatementBinder, "bind") as mock_binder:
+            binder = StatementBinder(StatementBinderContext())
+            binder._bind_upload_statement(upload_statement)
+            mock_binder.assert_any_call(upload_statement.table_ref)
+            mock_create.assert_any_call("table_name")
+            mock_tve.assert_called_with(
+                col_name=column.name, table_alias="table_alias", col_object=column
+            )
+            mock_binder.assert_any_call(tve_return_value)
+            self.assertEqual(upload_statement.column_list, [tve_return_value])
+
     @patch("eva.binder.statement_binder.create_video_metadata")
     @patch("eva.binder.statement_binder.TupleValueExpression")
     def test_bind_load_data(self, mock_tve, mock_create):
@@ -246,6 +284,24 @@ class StatementBinderTests(unittest.TestCase):
             mock_tve.assert_not_called()
             mock_binder.assert_any_call(column)
 
+    @patch("eva.binder.statement_binder.create_video_metadata")
+    @patch("eva.binder.statement_binder.TupleValueExpression")
+    def test_bind_upload_data(self, mock_tve, mock_create):
+        upload_statement = MagicMock()
+        column = MagicMock()
+        upload_statement.column_list = [column]
+
+        table_ref_obj = MagicMock()
+        table_ref_obj.columns = [column]
+
+        with patch.object(StatementBinder, "bind") as mock_binder:
+            binder = StatementBinder(StatementBinderContext())
+            binder._bind_upload_statement(upload_statement)
+            mock_binder.assert_any_call(upload_statement.table_ref)
+            mock_create.assert_not_called()
+            mock_tve.assert_not_called()
+            mock_binder.assert_any_call(column)
+
     @patch("eva.binder.statement_binder.create_video_metadata")
     @patch("eva.binder.statement_binder.TupleValueExpression")
     def test_bind_load_data_raises(self, mock_tve, mock_create):
@@ -258,6 +314,18 @@ class StatementBinderTests(unittest.TestCase):
                 binder = StatementBinder(StatementBinderContext())
                 binder._bind_load_data_statement(load_statement)
 
+    @patch("eva.binder.statement_binder.create_video_metadata")
+    @patch("eva.binder.statement_binder.TupleValueExpression")
+    def test_bind_upload_raises(self, mock_tve, mock_create):
+        upload_statement = MagicMock()
+        column = MagicMock()
+        upload_statement.column_list = [column]
+        upload_statement.table_ref.table.table_obj = None
+        with self.assertRaises(RuntimeError):
+            with patch.object(StatementBinder, "bind"):
+                binder = StatementBinder(StatementBinderContext())
+                binder._bind_upload_statement(upload_statement)
+
     def test_bind_unknown_object(self):
         class UnknownType:
             pass
