@@ -19,15 +19,28 @@ import pandas as pd
 from eva.executor.function_scan_executor import FunctionScanExecutor
 from eva.expression.function_expression import FunctionExpression
 from eva.models.storage.batch import Batch
+from eva.parser.alias import Alias
 
 
 class FunctionScanExecutorTest(unittest.TestCase):
     def test_simple_function_scan(self):
         values = Batch(pd.DataFrame([1, 2, 3], columns=["a"]))
-        expression = FunctionExpression(lambda x: x + 1, name="test", alias="test")
-        expression.output_col_aliases = ["test.a"]
-        plan = type("FunctionScanPlan", (), {"func_expr": expression})
+        expression = FunctionExpression(
+            lambda x: x + 1,
+            name="test",
+            alias=Alias(
+                "test",
+                ["a"],
+            ),
+        )
+        expression.projection_columns = "a"
+        plan = type(
+            "FunctionScanPlan",
+            (),
+            {"func_expr": expression, "do_unnest": False},
+        )
         function_scan_executor = FunctionScanExecutor(plan)
         actual = list(function_scan_executor.exec(lateral_input=values))[0]
+        print(actual.frames)
         expected = Batch(pd.DataFrame([2, 3, 4], columns=["test.a"]))
         self.assertEqual(expected, actual)
